/*
	config-wrap.h -- wrapper for config.h
	(C) Wouter Coene, 2000

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/
/*
	This file takes care of the config.h stuff. It's a bit messy, but as
	all the mess is concentrated here, the rest of the project can stay
	clean.
*/
/*
	You can define the following macro's to include certain files:

		#define		includes
		--------------- -----------------------------------------
		WANT_UNISTD	<unistd.h> if existant
		WANT_SYS_TYPES	<sys/types.h> if existant
		WANT_DIRENT	<dirent.h> or other
		WANT_TIME	<time.h> and/or <sys/time.h>
		WANT_WAIT	<sys/wait.h> and defines other macro's

	Other include files are considered safe to include directly.
*/

#ifndef CONFIG_WRAP_H_
#define CONFIG_WRAP_H_ 1

#define _GNU_SOURCE

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif /* HAVE_CONFIG_H */

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#if STDC_HEADERS
# include <string.h>
#else /* STDC_HEADERS */
# ifndef HAVE_STRCHR
#  define strchr index
#  define strrchr rindex
# else /* ! HAVE_STRCHR */
#  define NULL ((void *)0)
char *strchr(), *strrchr();
# endif /* HAVE_STRCHR */
# ifndef HAVE_MEMCPY
#  define memcpy(d, s, n) bcopy ((s), (d), (n))
#  define memmove(d, s, n) bcopy ((s), (d), (n))
# endif /* HAVE_MEMCPY */
#endif /* STDC_HEADERS */

#ifdef WANT_UNISTD
# ifdef HAVE_UNISTD_H
#  include <unistd.h>
# endif /* HAVE_UNISTD_H */
#endif /* WANT_UNISTD */

#ifdef WANT_SYS_TYPES
# ifdef HAVE_UNISTD_H
#  include <sys/types.h>
# endif /* HAVE_UNISTD_H */
#endif /* WANT_SYS_TYPES */

#ifdef WANT_DIRENT
# if HAVE_DIRENT_H
#  include <dirent.h>
#  define NAMLEN(dirent) strlen((dirent)->d_name)
# else /* HAVE_DIRENT_H */
#  define dirent direct
#  define NAMLEN(dirent) (dirent)->d_namlen
#  if HAVE_SYS_NDIR_H
#   include <sys/ndir.h>
#  endif /* HAVE_SYS_NDIR_H */
#  if HAVE_SYS_DIR_H
#   include <sys/dir.h>
#  endif /* HAVE_SYS_DIR_H */
#  if HAVE_NDIR_H
#   include <ndir.h>
#  endif /* HAVE_NDIR_H */
# endif /* HAVE_DIRENT_H */
#endif /* WANT_DIRENT */

#ifdef WANT_TIME
# if TIME_WITH_SYS_TIME
#  include <sys/time.h>
#  include <time.h>
# else /* TIME_WITH_SYS_TIME */
#  if HAVE_SYS_TIME_H
#   include <sys/time.h>
#  else /* HAVE_SYS_TIME_H */
#   include <time.h>
#  endif /* HAVE_SYS_TIME_H */
# endif /* TIME_WITH_SYS_TIME */
#endif /* WANT_TIME */

#ifdef WANT_STRFRY
# ifndef HAVE_STRFRY
#  define strfry(x)
# endif /* HAVE_STRFRY */
#endif /* WANT_STRFRY */

#ifdef WANT_WAIT
# if HAVE_SYS_WAIT_H
#  include <sys/wait.h>
# endif /* HAVE_SYS_WAIT_H */
# ifndef WEXITSTATUS
#  define WEXITSTATUS(stat_val) ((unsigned)(stat_val) >> 8)
# endif /* WEXITSTATUS */
# ifndef WIFEXITED
#  define WIFEXITED(stat_val) (((stat_val) & 255) == 0)
# endif /* WIFEXITED */
#endif /* WANT_WAIT */

#endif

/* end config-wrap.h */
